==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v1/model/notebooks_response.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.notebooks_response_data import NotebooksResponseData
    from datadog_api_client.v1.model.notebooks_response_meta import NotebooksResponseMeta

    globals()["NotebooksResponseData"] = NotebooksResponseData
    globals()["NotebooksResponseMeta"] = NotebooksResponseMeta


class NotebooksResponse(ModelNormal):

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "data": ([NotebooksResponseData],),
            "meta": (NotebooksResponseMeta,),
        }

    attribute_map = {
        "data": "data",
        "meta": "meta",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """
        Notebooks get all response.

        :param data: List of notebook definitions.
        :type data: [NotebooksResponseData], optional

        :param meta: Searches metadata returned by the API.
        :type meta: NotebooksResponseMeta, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(NotebooksResponse, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self

==> datadog-api-client-1.11.0.tar.gz: datadog-api-client-1.11.0/src/datadog_api_client/v1/model/notebooks_response.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.notebooks_response_data import NotebooksResponseData
    from datadog_api_client.v1.model.notebooks_response_meta import NotebooksResponseMeta

    globals()["NotebooksResponseData"] = NotebooksResponseData
    globals()["NotebooksResponseMeta"] = NotebooksResponseMeta


class NotebooksResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        lazy_import()
        return {
            "data": ([NotebooksResponseData],),
            "meta": (NotebooksResponseMeta,),
        }

    attribute_map = {
        "data": "data",
        "meta": "meta",
    }

    def __init__(self, *args, **kwargs):
        """
        Notebooks get all response.

        :param data: List of notebook definitions.
        :type data: [NotebooksResponseData], optional

        :param meta: Searches metadata returned by the API.
        :type meta: NotebooksResponseMeta, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(NotebooksResponse, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
